==> bootlaterus-0.1.4.tgz: package/README.md <==
# Bootlaterus

> Find Bootlaterus showcase and starter guide at the [**Official Site**](https://equilaterus.github.io/bootlaterus/)

Bootlaterus **includes Bootstrap v4** and has **extended components** that don't require additional Javascript to work.

Build a great responsive UI with a **Compatible** and **Easy to use** *Bootstrap Superset*.


## Features

* Includes CSS components and helpers from *Bootstrap v4* so you'll work on a familiar and compatible environment.
* [Custom CSS components](https://github.com/equilaterus/bootlaterus/wiki/Custom-components) to create *Side Navbars*, *Carousels that work with images of different sizes*, *Backgrounds* and *Utilities* making even easier to use *Bootstrap*. 
* Bootlaterus doesn't require additional JS files to work, so it is **100% compatible** with *Bootstrap Default jQuery implementation* but also with ports like [React-Bootstrap](https://react-bootstrap.github.io/), [ReactStrap](https://reactstrap.github.io/), [ng-bootstrap](https://ng-bootstrap.github.io/#/home), [bootstrap+vuejs](https://bootstrap-vue.js.org/) and almost any JS implementation of Bootstrap Components.
* Multiple themes including color and font variations. [See all available variations here](https://github.com/equilaterus/bootlaterus/wiki/Theme-variations)
* Custom templates for general use applications like stores or social networks and also for Wiki-like pages, GitHub Pages or documentation-sites.
* All our build scripts and infrastructure code is open source so you can use it to create your own themes.


## Builds

* **Release**

  [![Build Status](https://travis-ci.org/equilaterus/bootlaterus.svg?branch=release)](https://travis-ci.org/equilaterus/bootlaterus/branches)  [![npm version](https://badge.fury.io/js/bootlaterus.svg)](https://badge.fury.io/js/bootlaterus)

* **Master**

  [![Build Status](https://travis-ci.org/equilaterus/bootlaterus.svg?branch=master)](https://travis-ci.org/equilaterus/bootlaterus/branches)

* **Dev** Unstable

  [![Build Status](https://travis-ci.org/equilaterus/bootlaterus.svg?branch=dev)](https://travis-ci.org/equilaterus/bootlaterus/branches) 

## More info

* Bootlaterus:
  * [Official Page](https://equilaterus.github.io/bootlaterus/) 
  * [Wiki](https://github.com/equilaterus/bootlaterus/wiki)

* Bootstrap: 
  * [Official Docs](https://getbootstrap.com/docs/4.3/getting-started/introduction/)

*  **GitHub Pages**: Easily integrate Bootlaterus (or vanilla Bootstrap) with [pages.github.com](https://pages.github.com) using [bootlaterus.gh-pages](https://github.com/equilaterus/bootlaterus.gh-pages)

This project is being developed and maintained by [Equilaterus](https://equilaterus.github.io/).

==> bootlaterus-0.2.0.tgz: package/README.md <==
![](https://i.imgur.com/R9yZwGq.png)

# Bootlaterus

[![](https://data.jsdelivr.com/v1/package/npm/bootlaterus/badge)](https://www.jsdelivr.com/package/npm/bootlaterus) [![npm version](https://badge.fury.io/js/bootlaterus.svg)](https://badge.fury.io/js/bootlaterus)

> Find Bootlaterus showcase and starter guide at the [**Official Site**](https://equilaterus.github.io/bootlaterus/)

Bootlaterus **includes Bootstrap v4** and has **extended components** that don't require additional Javascript to work.

Build a great responsive UI with **Bootlaterus**, the **Compatible** and **Friendly** *Bootstrap Superset*.


## Features

* Includes CSS components and helpers from *Bootstrap v4* so you'll work on a familiar and compatible environment.
* [Custom CSS components](https://equilaterus.github.io/bootlaterus/docs.html) to create *Side Navbars*, *Extended Carousels*, *Backgrounds*, *Beautiful Gradients* and many *Utilities* that make even easier to use *Bootstrap*. 
* Bootlaterus doesn't require additional JS files to work, so it is **100% compatible** with *Bootstrap Default jQuery implementation* but also with ports like [React-Bootstrap](https://react-bootstrap.github.io/), [ReactStrap](https://reactstrap.github.io/), [ng-bootstrap](https://ng-bootstrap.github.io/#/home), [bootstrap+vuejs](https://bootstrap-vue.js.org/) and almost any JS implementation of Bootstrap Components.
* Multiple themes including color and font variations. [See all available variations here](https://equilaterus.github.io/bootlaterus/docs.html#themes)
* All our build scripts are open source so you can use them to create your own themes.


## Builds

* **Release**

  [![Build Status](https://travis-ci.org/equilaterus/bootlaterus.svg?branch=release)](https://travis-ci.org/equilaterus/bootlaterus/branches)  [![npm version](https://badge.fury.io/js/bootlaterus.svg)](https://badge.fury.io/js/bootlaterus)

* **Master**

  [![Build Status](https://travis-ci.org/equilaterus/bootlaterus.svg?branch=master)](https://travis-ci.org/equilaterus/bootlaterus/branches)

* **Dev** Unstable

  [![Build Status](https://travis-ci.org/equilaterus/bootlaterus.svg?branch=dev)](https://travis-ci.org/equilaterus/bootlaterus/branches) 

## More info

* Bootlaterus:
  * [Official Page](https://equilaterus.github.io/bootlaterus/) 
  * [Docs](https://equilaterus.github.io/bootlaterus/docs.html)

* Bootstrap: 
  * [Official Docs](https://getbootstrap.com/docs/4.3/getting-started/introduction/)

*  **GitHub Pages**: Easily integrate Bootlaterus (or vanilla Bootstrap) with [pages.github.com](https://pages.github.com) using [bootlaterus.gh-pages](https://github.com/equilaterus/bootlaterus.gh-pages)

This project is being developed and maintained by [Equilaterus](https://equilaterus.github.io/).
